from xml.etree import cElementTree as eTree

from bustoken import TK_SITEF_ADD_PAYMENT
from msgbus import (
    FM_PARAM,
    TK_SYS_ACK,
    MBEasyContext,
)
from mw_helper import show_message_dialog
from sysactions import (
    get_used_service,
    show_messagebox,
    close_asynch_dialog,
)
from systools import sys_log_exception
from typing import (
    Optional,
    List,
)

from actions.eft import get_tender_id


def request_eft(
    pos_id,                     # type: str
    mb_context,                 # type: MBEasyContext
    model,                      # type: eTree.XML
    is_credit,                  # type: bool
    amount,                     # type: float
    _eft_events,                # type: List
    is_mercadopago=False,       # type: bool
    is_table_service=False,     # type: bool
):
    # type: (...) -> Optional[str]

    from poslistener import eft_status_finish

    order = model.find("CurrentOrder/Order")
    totaled_state = order.findall("StateHistory/State[@state='TOTALED']")[-1]
    last_totaled = totaled_state.get("timestamp").replace("-", "").replace(":", "")

    if is_credit:
        tender_type = 1
    else:
        tender_type = 122 if is_mercadopago else 2

    order_id = order.get("orderId")
    all_tenders = order.find("TenderHistory").findall("Tender")
    tender_id = get_tender_id(all_tenders, is_table_service)

    fiscal_date = last_totaled[:8]
    fiscal_time = last_totaled[9:15]
    operator = model.find("Operator").get("id")
    eft_name = get_used_service(model, "eft")

    dialog_id = show_message_dialog(pos_id, "$INFORMATION", "$WAITING_SITEF_ADD_PAYMENT", "NOCONFIRM", True)
    try:
        component_name = eft_name or "Sitef%02d" % int(pos_id)
        evt_data = [eft_name, None, pos_id, order_id]
        _eft_events.append(evt_data)

        data = "%s;%s;%s;%s;%s;%s;%s;%s;%s" % (
            str(pos_id),
            str(order_id),
            str(operator),
            str(tender_type),
            str(amount),
            fiscal_date,
            fiscal_time,
            tender_id,
            False
        )

        response = mb_context.MB_EasySendMessage(component_name, TK_SITEF_ADD_PAYMENT, FM_PARAM, data)
        if response.token != TK_SYS_ACK:
            return

        return response.data
    except Exception as _: # noqa
        show_messagebox(pos_id, "$ERROR_PROCESSING_TEF", "$EFT", asynch=True, buttons="$OK")
        sys_log_exception("Error processing TEF")
    finally:
        eft_status_finish([pos_id])
        close_asynch_dialog(pos_id, dialog_id)






import json
import time

from messagebus import Event
from model import PaymentResponseMessage
from paymentprocessor import PaymentProcessor
from msgbus import MBException


class MobileSitefPaymentProcessor(PaymentProcessor):
    def connection_status(self, test_connection_data):
        return True

    def add_payment(self, start_payment_data):
        return PaymentResponseMessage("Mobile Sitef cannot process transactions")

    def cancel_payment(self):
        pass  # Mobile Sitef doesn't handle cancel non-finished transactions

    def finish_payment(self, finish_payment_data):
        pos_id = finish_payment_data.pos_id
        order_id = finish_payment_data.order_id
        status = finish_payment_data.status
        fiscal_date = finish_payment_data.fiscal_date
        fiscal_time = finish_payment_data.fiscal_time
        transaction_data = {
            "timeStamp": time.time(),
            "confirmTransaction": status,
            "transactionIdentifier": str(pos_id) + str(order_id),
            "fiscalDate": fiscal_date,
            "fiscalTime": fiscal_time
        }

        data = json.dumps(transaction_data)
        retry = 0
        while retry < 3:
            try:
                event_xml = """<Event subject="POS{}" type="MOBILE">
                                   <MOBILE_CONFIRM_TRANSACTION>
                                       {}
                                   </MOBILE_CONFIRM_TRANSACTION>
                               </Event>""".format(pos_id, data)

                self.message_bus.publish_event(Event("POS{}".format(int(pos_id)), "MOBILE", event_xml))
            except MBException:
                self.logger.exception("Error sending mobile confirm transaction")
            finally:
                retry += 1

    def get_name(self):
        return "MobileSitef"



from ._PaymentProcessor import PaymentProcessor
from ._FakePaymentProcessor import FakePaymentProcessor
from ._ConectCarPaymentProcessor import ConectCarPaymentProcessor
from .sitef import SitefDebitPaymentProcessor, SitefCreditPaymentProcessor, SitefMercadoPagoPaymentProcessor,\
    MobileSitefPaymentProcessor
from .cappta import CapptaCreditPaymentProcessor, CapptaDebitPaymentProcessor




import json
import logging
import base64

from xml.etree import cElementTree as eTree
from actions.eft import get_electronic_tenders, has_electronic_payment
from bustoken import TK_SITEF_FINISH_PAYMENT, TK_SITEF_NOT_ALL_PAYMENTS_REFUNDED, TK_SITEF_REFUND_CANCELED
from msgbus import FM_PARAM, TK_SYS_ACK
from sysactions import (
    mbcontext,
    get_model,
    get_used_service,
    show_messagebox,
    StopAction
)

logger = logging.getLogger("TableActions")


def finish_eft_transactions(
    pos_id,                 # type: str
    order,                  # type: eTree
    status,                 # type: str
    tender_id="",           # type: str
    is_table_service=False  # type: bool
):
    # type: (...) -> None

    totaled_states = order.findall("StateHistory/State[@state='TOTALED']")
    if len(totaled_states) == 0:
        return

    model = get_model(pos_id)
    component_name = get_used_service(model, "eft")
    if component_name is None:
        return

    last_totaled = totaled_states[-1]
    last_totaled_date = last_totaled.get("timestamp").replace("-", "").replace(":", "")

    order_id = order.get("orderId")
    fiscal_date = last_totaled_date[:8]
    fiscal_time = last_totaled_date[9:15]

    status = status if has_electronic_payment(order) or is_table_service else "0"
    tenders = get_electronic_tenders(order)
    tender_details_str = base64.b64encode(json.dumps(tenders))

    data = ";".join([str(pos_id), order_id, fiscal_date, fiscal_time, status, tender_details_str, tender_id])
    _finish_transaction(pos_id, order_id, status, data, component_name)


def _finish_transaction(
    pos_id,             # type: str
    order_id,           # type: str
    status,             # type: str
    data,               # type: str
    component_name,     # type: str
):
    # type: (...) -> None

    for try_num in range(1, 4):
        try:
            msg = "[finish_eft_transactions] Trying to send a finish message. Order #: {}; Try #: {}; STATUS #: {}"
            logger.info(msg.format(order_id, try_num, status))
            ten_minutes_timeout = 600000000
            ret = mbcontext.MB_EasySendMessage(
                component_name,
                TK_SITEF_FINISH_PAYMENT,
                FM_PARAM,
                data,
                ten_minutes_timeout
            )

            if ret.token == TK_SYS_ACK:
                logger.info("[finish_eft_transactions] Success finished eft transaction. Order #: {}".format(order_id))
                return
            elif ret.token == TK_SITEF_NOT_ALL_PAYMENTS_REFUNDED:
                show_messagebox(pos_id, "$SOME_PAYMENTS_WERE_NOT_REFUNDED")
                continue
            elif ret.token == TK_SITEF_REFUND_CANCELED:
                raise StopAction()

            message = "[finish_eft_transactions] ACK not received. Order #: {} - {} - {}"
            logger.info(message.format(order_id, ret.token, ret.data))
            _show_internal_error_message(pos_id, status)

        except Exception as ex:
            if isinstance(ex, StopAction):
                raise ex

            _show_internal_error_message(pos_id, status)

            msg = "[finish_eft_transactions] Error sending message. Order #: {} / Try #: {} / Status: {}"
            msg = msg.format(order_id, try_num, status)
            if try_num == 3:
                logger.exception(msg, exc_info=True)
            else:
                logger.info(msg)

    _show_manual_process_message(pos_id, status)


def _show_internal_error_message(
    pos_id,     # type: str
    status      # type: str
):
    # type: (...) -> None

    _display_message(
        pos_id,
        status,
        "$INTERNAL_ERROR_REFUNDING_ELECTRONIC_PAYMENTS",
        "$INTERNAL_ERROR_CONFIRMING_ELECTRONIC_PAYMENTS"
    )


def _show_manual_process_message(
    pos_id,     # type: str
    status      # type: str
):
    # type: (...) -> None

    _display_message(
        pos_id,
        status,
        "$ERROR_REFUNDING_ELECTRONIC_PAYMENTS_MANUAL_PROCESS_NEEDED",
        "$ERROR_CONFIRMING_ELECTRONIC_PAYMENTS_MANUAL_PROCESS_NEEDED"
    )


def _display_message(
    pos_id,             # type: str
    status,             # type: str
    error_refunding,    # type: str
    error_confirming    # type: str
):
    # type: (...) -> None

    message = error_refunding if status == "0" else error_confirming
    show_messagebox(pos_id, message)



from ._ElectronicPaymentCloseDialogProcessor import ElectronicPaymentCloseDialogProcessor
from ._ElectronicPaymentShowBarcodeProcessor import ElectronicPaymentShowBarcodeProcessor
from ._ElectronicPaymentShowChoicesProcessor import ElectronicPaymentShowChoicesProcessor
from ._ElectronicPaymentShowInputProcessor import ElectronicPaymentShowInputProcessor
from ._ElectronicPaymentShowMessageProcessor import ElectronicPaymentShowMessageProcessor
from ._ElectronicPaymentShowQuestionProcessor import ElectronicPaymentShowQuestionProcessor



from ._SitefPaymentProcessor import SitefPaymentProcessor

_current_sitef_processor = None


def stop_sitef_processor():
    global _current_sitef_processor
    if _current_sitef_processor:
        _current_sitef_processor.stop()
    _current_sitef_processor = None


def get_sitef_processor(message_bus, dialog_manager, config, logger):
    global _current_sitef_processor
    if not _current_sitef_processor:
        _current_sitef_processor = SitefPaymentProcessor(message_bus, dialog_manager, config, logger)
    return _current_sitef_processor



# -*- coding: utf-8 -*-
from typing import Dict


class CardBrand(object):

    def __init__(
        self
    ):
        self.brands = self._get_all_card_brands()

    def get_brand_code(
        self,
        brand   # type: str
    ):
        # type: (...) -> str

        brand = int(brand)
        return self.brands[brand]["sitef_brand_code"] if brand in self.brands.keys() else "99"

    @staticmethod
    def _get_all_card_brands():
        # type: (...) -> Dict[str, int]

        return {
            1: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'ABN'},
            2: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'ABRAPETITE'},
            3: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'ACC-CARD'},
            4: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'ACEITO'},
            5: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'ACSP'},
            6: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'AGIPLAN'},
            7: {'sitef_brand_code': '10', 'sitef_brand_name': 'Alelo', 'cappta_brand_name': 'ALELO'},
            8: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'AMAZONIA CELULAR'},
            9: {'sitef_brand_code': '03', 'sitef_brand_name': 'American Express', 'cappta_brand_name': 'AMEX'},
            10: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'ASCARD'},
            11: {'sitef_brand_code': '08', 'sitef_brand_name': 'Aura', 'cappta_brand_name': 'AURA'},
            12: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'AURA BERGAMAIS'},
            13: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'AURA FNAC'},
            14: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'AVISTA'},
            15: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'BANCRED'},
            16: {'sitef_brand_code': '11', 'sitef_brand_name': 'Banes Card', 'cappta_brand_name': 'BANESCARD'},
            17: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'BANESE CARD'},
            18: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'BANESTIK'},
            19: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'BANKCARD'},
            20: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'BANKTEC'},
            21: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'BANPARA'},
            22: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'BANQUET'},
            23: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'BANQUET SMART'},
            24: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'BANRICOMPRAS'},
            25: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'BANRISUL'},
            26: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'BANRISUL ALIMENTACAO'},
            27: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'BANRISUL COMBUSTIVEL'},
            28: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'BASECARD'},
            29: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'BEM'},
            30: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'BIGCARD'},
            31: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'BLACKHAWK'},
            32: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'BNB CLUBE'},
            33: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'BNDES'},
            34: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'BONUS'},
            35: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'BRADESCO'},
            36: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'BRASILCARD'},
            37: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'BRT FIXA'},
            38: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'BRTELECOM'},
            39: {'sitef_brand_code': '09', 'sitef_brand_name': 'Cabal', 'cappta_brand_name': 'CABAL CRED'},
            40: {'sitef_brand_code': '09', 'sitef_brand_name': 'Cabal', 'cappta_brand_name': 'CABAL DEB'},
            41: {'sitef_brand_code': '09', 'sitef_brand_name': 'Cabal', 'cappta_brand_name': 'CABAL VALE'},
            42: {'sitef_brand_code': '12', 'sitef_brand_name': 'CalCard ', 'cappta_brand_name': 'CALCARD'},
            43: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'CARDCO'},
            44: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'CARTAO BRINQUEDO'},
            45: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'CARTAO MAMAE'},
            46: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'CARTAO NATAL'},
            47: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'CB-BANCO DO BRASIL'},
            48: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'CB-BRADESCO'},
            49: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'CB-CITIBANK'},
            50: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'CB-HSBC'},
            51: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'CB-UNIBANCO'},
            52: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'CELULAR'},
            53: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'CHECKCHECK'},
            54: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'CHEQUE ELETRONICO'},
            55: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'CHEQUEPRE'},
            56: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'CIELO'},
            57: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'CLARO'},
            58: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'CLARO OFF-LINE'},
            59: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'COLABORADOR'},
            60: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'COM VOCE'},
            61: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'COMPROCARD'},
            62: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'CONSTRUCARD'},
            63: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'CONVCARD'},
            64: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'COOPERCRED VALE'},
            65: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'CPF'},
            66: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'CREDI-SHOP'},
            67: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'CREDITEM'},
            68: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'CREDPAR'},
            69: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'CREDSYSTEM'},
            70: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'CTBC-CELULAR'},
            71: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'CTBC-FIXO'},
            72: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'DACASA'},
            73: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'DIAMANTE'},
            74: {'sitef_brand_code': '05', 'sitef_brand_name': 'Diners Club', 'cappta_brand_name': 'DINERS'},
            75: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'DMCARD'},
            76: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'ECXCARD'},
            77: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'ELAVON'},
            78: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'ELECTRON'},
            79: {'sitef_brand_code': '06', 'sitef_brand_name': 'Elo', 'cappta_brand_name': 'ELO CREDITO'},
            80: {'sitef_brand_code': '06', 'sitef_brand_name': 'Elo', 'cappta_brand_name': 'ELO DEBITO'},
            81: {'sitef_brand_code': '06', 'sitef_brand_name': 'Elo', 'cappta_brand_name': 'ELO VOUCHER'},
            82: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'EMBRATEL'},
            83: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'EMBRATEL LIVRE ONLINE'},
            84: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'EPAY'},
            85: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'EPAY SEGUROS'},
            86: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'EPHARMA'},
            87: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'EPHARMA BALCAO'},
            88: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'EVANGELICO'},
            89: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'FACIL'},
            90: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'FACIL_LOSANGO'},
            91: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'FAI'},
            92: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'FALA FACIL'},
            93: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'FANCARD'},
            94: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'FARMASEG'},
            95: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'FIC'},
            96: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'FININVEST'},
            97: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'FLEXMED'},
            98: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'FORTBRASIL'},
            99: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'FUNCIONAL CARD'},
            100: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'GETNET'},
            101: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'GIVEX'},
            102: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'GOIASCARD'},
            103: {'sitef_brand_code': '15', 'sitef_brand_name': 'GoodCard', 'cappta_brand_name': 'GOODCARD'},
            104: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'GOODMED'},
            105: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'GOODVALE'},
            106: {'sitef_brand_code': '16', 'sitef_brand_name': 'GreenCard', 'cappta_brand_name': 'GREENCARD'},
            107: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'GYNCARD'},
            108: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'HAPPY CARD'},
            109: {'sitef_brand_code': '07', 'sitef_brand_name': 'Hipercard', 'cappta_brand_name': 'HIPERCARD'},
            110: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'IBI'},
            111: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'IBICARD'},
            112: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'IBIPL'},
            113: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'INCOMM'},
            114: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'INFOCARDS'},
            115: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'ITAU'},
            116: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'ITAU-MOBILE'},
            117: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'J.C.B.'},
            118: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'JETPARCARD'},
            119: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'LEADER CARD'},
            120: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'LOJISTA'},
            121: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'LOSANGO'},
            122: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'MAESTRO'},
            123: {'sitef_brand_code': '19', 'sitef_brand_name': 'Mais', 'cappta_brand_name': 'MAIS!'},
            124: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'MARISA'},
            125: {'sitef_brand_code': '02', 'sitef_brand_name': 'Mastercard', 'cappta_brand_name': 'MASTERCARD'},
            126: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'MAXICRED'},
            127: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'MEDCHEQUE'},
            128: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'MINASCRED'},
            129: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'MULTIALIMENTACAO'},
            130: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'MULTIALIMENTACAO BEN'},
            131: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'MULTIBENEFICIO'},
            132: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'MULTIBENEFICIOS'},
            133: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'MULTICASH'},
            134: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'MULTICESTABASICA'},
            135: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'MULTICHEQUE'},
            136: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'MULTICHEQUE ANTIGO'},
            137: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'MULTICHEQUE BEN'},
            138: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'MULTICOMBUSTIVEL'},
            139: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'MULTICULTURA'},
            140: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'MULTIEMPRESARIAL'},
            141: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'MULTIFARMA'},
            142: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'MULTIREFEICAO'},
            143: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'MURY'},
            144: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'NBC'},
            145: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'NEUS'},
            146: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'NEXTEL'},
            147: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'NOKIA'},
            148: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'NOVARTIS'},
            149: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'NUTRICARD/BONUSCRED'},
            150: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'NUTRICASH'},
            151: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'OBOÉCARD'},
            152: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'OI'},
            153: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'OI FIXA'},
            154: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'OI OFF'},
            155: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'ORGCARD CRED'},
            156: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'ORGCARD DEB'},
            157: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'ORGCARD DVCS'},
            158: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros',
                  'cappta_brand_name': 'PAGUE CONTAS VISANET 4.1'},
            159: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'PBMGOV'},
            160: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'PERSONAL CARD'},
            161: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'PHARMASYSTEM'},
            162: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'PL FREECENTER'},
            163: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'PL GETNET MASTER'},
            164: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'PL GETNET VISA'},
            165: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'PL MAGAZINE'},
            166: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'PL TESOURA'},
            167: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'PLANVALE'},
            168: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'PLANVALE R'},
            169: {'sitef_brand_code': '21', 'sitef_brand_name': 'Policard', 'cappta_brand_name': 'POLICARD'},
            170: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'PORTALCARD'},
            171: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'POUPCARD'},
            172: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'PRATICARD'},
            173: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'PREMIACAO'},
            174: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'PREMIUM'},
            175: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'PRESENTE'},
            176: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'PRESTASERV'},
            177: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'PREVSAUDE'},
            178: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'PREZUNIC'},
            179: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros',
                  'cappta_brand_name': 'PRIVATE LABEL REDECARD'},
            180: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'QUALYCARD'},
            181: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'RAINBOW'},
            182: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros',
                  'cappta_brand_name': 'RANCHO CARD ALIMENTACAO'},
            183: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'RANCHO CARD CONVENIO'},
            184: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'REC-FININVEST'},
            185: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'REDECARD'},
            186: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'REDESOFTNEX'},
            187: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'REDESOFTNEX CONV'},
            188: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'REFEISUL'},
            189: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'ROSSI'},
            190: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'SAFRA AMANCO'},
            191: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'SAPORE'},
            192: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'SENFF'},
            193: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'SERASA'},
            194: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'SERCOMTEL-CELULAR'},
            195: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'SERCOMTEL-FIXO'},
            196: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'SICREDI CREDITO'},
            197: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'SICREDI DEBITO'},
            198: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'SIFRAGO'},
            199: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'SIMCRED'},
            200: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'SISCRED'},
            201: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'SISTEMA'},
            202: {'sitef_brand_code': '23', 'sitef_brand_name': 'Sodexo', 'cappta_brand_name': 'SODEXO ALIMENTACAO'},
            203: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'SODEXO REFEICAO'},
            204: {'sitef_brand_code': '23', 'sitef_brand_name': 'Sodexo', 'cappta_brand_name': 'SOLLO'},
            205: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'SOLUCARD'},
            206: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'SOMAR'},
            207: {'sitef_brand_code': '04', 'sitef_brand_name': 'Sorocred', 'cappta_brand_name': 'SOROCRED'},
            208: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'SOROCRED CREDITO'},
            209: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'STAFFCARD'},
            210: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'SUPER BONUS'},
            211: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'SUPERCARD'},
            212: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'SYSDATA'},
            213: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'TECBAN'},
            214: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'TELECHEQUE'},
            215: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'TELEFONICA'},
            216: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'TELEFONIC-FAMILIA'},
            217: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'TELEMAR'},
            218: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'TELEMIG'},
            219: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'TELENET'},
            220: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'TELESP-SUPER 15'},
            221: {'sitef_brand_code': '27', 'sitef_brand_name': 'Ticket', 'cappta_brand_name': 'TICKET ALIMENTAÇÃO'},
            222: {'sitef_brand_code': '27', 'sitef_brand_name': 'Ticket', 'cappta_brand_name': 'TICKET CAR'},
            223: {'sitef_brand_code': '27', 'sitef_brand_name': 'Ticket', 'cappta_brand_name': 'TICKET RESTAURANTE'},
            224: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'TIM'},
            225: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'TIM ON-LINE'},
            226: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'TIPCARD'},
            227: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'TMS'},
            228: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'TOKORO'},
            229: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'TOPCARD'},
            230: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'TOPPREMIUM'},
            231: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'TRANSCHECK'},
            232: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'TRICARD'},
            233: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'TRNCENTRE'},
            234: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'UNIK'},
            235: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'UNNISA'},
            236: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'USECRED'},
            237: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'VAELETRONICO'},
            238: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'VALE MAIS'},
            239: {'sitef_brand_code': '24', 'sitef_brand_name': 'ValeCard', 'cappta_brand_name': 'VALECARD'},
            240: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'VALECASH'},
            241: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'VALEFROTA'},
            242: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'VALEGAS'},
            243: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'VALESHOP'},
            244: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'VALETIK'},
            245: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'VEGAS CARD'},
            246: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'VERDECARD'},
            247: {'sitef_brand_code': '25', 'sitef_brand_name': 'Verocheque', 'cappta_brand_name': 'VEROCHEQUE'},
            248: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'VIA FINANCEIRA'},
            249: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'VIDALINK'},
            250: {'sitef_brand_code': '01', 'sitef_brand_name': 'Visa', 'cappta_brand_name': 'VISA'},
            251: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'VIVO'},
            252: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'VIVO OFF-LINE'},
            253: {'sitef_brand_code': '26', 'sitef_brand_name': 'VR', 'cappta_brand_name': 'VR ALIMENTACAO'},
            254: {'sitef_brand_code': '26', 'sitef_brand_name': 'VR', 'cappta_brand_name': 'VR AUTO'},
            255: {'sitef_brand_code': '26', 'sitef_brand_name': 'VR', 'cappta_brand_name': 'VR CULTURA'},
            256: {'sitef_brand_code': '26', 'sitef_brand_name': 'VR', 'cappta_brand_name': 'VR REFEICAO'},
            257: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'ZOGBI'},
            259: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'SODEXO COMBUSTÍVEL'},
            260: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'ALGORIX'},
            261: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'ALGORIX_S'},
            262: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'SAVS'},
            263: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'VEROCHEQUE CREDITO'},
            265: {'sitef_brand_code': '13', 'sitef_brand_name': 'Credz', 'cappta_brand_name': 'CREDZ'},
            266: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'ESPLANADA'},
            267: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'SODEXO'},
            268: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'ELO REFEICAO'},
            269: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'ELO ALIMENTACAO'},
            270: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'PBM PADRAO'},
            271: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'CIELO AUTO'},
            273: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'BIGCARD DEB'},
            276: {'sitef_brand_code': '27', 'sitef_brand_name': 'Ticket', 'cappta_brand_name': 'TICKET ALIMENTACAO'},
            277: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'ALELO REFEICAO'},
            278: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'ALELO ALIMENTACAO'},
            279: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'BAHAMAS CRED'},
            280: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'BAHAMAS ALIM'},
            281: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'BANESCARD DEBITO'},
            283: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'FLEETCOR'},
            284: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'MAXXCARD'},
            285: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'METTACARD'},
            286: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'REDE CRED'},
            287: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'REDE DEB'},
            288: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'REDE VOUCHER'},
            289: {'sitef_brand_code': '17', 'sitef_brand_name': 'Hiper', 'cappta_brand_name': 'HIPER DEB'},
            290: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'ALGORIX-VOUCHER'},
            291: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'CREDIALIMENTACAO'},
            292: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'VISA VALE'},
            293: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'UAI CARD'},
            294: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'REDEMED'},
            295: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'PARACATUCARD'},
            296: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'VALECARD DEB'},
            297: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'MULTIPLUS'},
            298: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'POLICARD CREDITO'},
            299: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'POLICARD DEBITO'},
            300: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'POLICARD ALIMENTACAO'},
            301: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'POLICARD REFEICAO'},
            302: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'GOODCARD ALIMENTACAO'},
            303: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'GOODCARD REFEICAO'},
            304: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'ALELO REFEIÇÃO'},
            305: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'ALELO ALIMENTAÇÃO'},
            306: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'VEGAS CARD'},
            307: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'VEGAS CARD'},
            308: {'sitef_brand_code': '99', 'sitef_brand_name': 'Outros', 'cappta_brand_name': 'VALLE EXPRESS'}
        }



import base64
import os
import re
import time
from ctypes import c_long, create_string_buffer, addressof
from threading import Lock
from xml.etree import cElementTree as eTree

from messagebus import DataType, DefaultToken, Message
from model import PaymentResponseData, StartPaymentData, PaymentResponseMessage, PaymentResponse, FinishPaymentData

from ._SitefActions import SitefActions
from ._SitefParams import SitefParams
from ._SitefServiceFinder import SitefServiceFinder

TK_STORECFG_GET = 0x01300001
TK_SLCTRL_OMGR_ORDERPICT = 0x00A00002

API_INIT_OK = 0
API_LOOP_OK = 10000
API_LOOP_FINISHED = 0
API_NO_SITEF_COMMUNICATION = -5


def _get_terminal_id(pos_id):
    return "SW%06d" % int(pos_id)


def _api_has_data(command):
    return command.value == 0


def _format_api_error_response(api_ret):
    error_responses = {
        -2: PaymentResponseMessage("Cancelado"),
        -5: PaymentResponseMessage("Falha no Servidor SiTEF"),
        -6: PaymentResponseMessage("Operacao cancelada pelo usuario"),
        -40: PaymentResponseMessage("Nao Autorizado - SiTEF"),
        -43: PaymentResponseMessage("Erro PinPad"),
        -120: PaymentResponseMessage("Cancelado")
    }
    if api_ret > 0:
        return PaymentResponseMessage("Nao Autorizado")
    return error_responses.get(api_ret, PaymentResponseMessage("Falha na Operacao: Erro {}".format(api_ret)))


def _should_ignore_command(command):
    return command.value in (2, 4, 21, 14, 52)


def _get_dll_path(config):
    dll_path = config.find_value("DLLPath", "")
    for var in re.findall("{[a-zA-Z0-9]*}", dll_path):
        dll_path = dll_path.replace(var, os.environ.get(var.replace('{', '').replace('}', ''), ""))
    return os.path.normpath(os.path.join(dll_path, "clisitef32i.dll"))


class SitefPaymentProcessor(object):
    def __init__(self, message_bus, dialog_manager, config, logger):
        from ctypes import WinDLL
        self.logger = logger
        self.dialog_manager = dialog_manager
        self.message_bus = message_bus

        self.id_loja = config.find_value("IdLoja")
        self.timeout = config.find_value("Timeout")
        self.show_qr_code = config.find_value("ShowQRCode")
        dll_path = _get_dll_path(config)
        self.sitef_dll = WinDLL(dll_path)
        self.configura_sitef_interativo = self.sitef_dll["ConfiguraIntSiTefInterativo"]
        self.inicia_sitef_interativo = self.sitef_dll["IniciaFuncaoSiTefInterativo"]
        self.continua_sitef_interativo = self.sitef_dll["ContinuaFuncaoSiTefInterativo"]
        self.finaliza_sitef_interativo = self.sitef_dll["FinalizaFuncaoSiTefInterativo"]

        self.service_finder = SitefServiceFinder(self.timeout, config.find_values("IP") or [], self.id_loja,
                                                 config.find_value("PosId"), self.logger, dll_path)

        self.current_ip = None
        self.current_order = None

        self.cancel = False
        self.cancel_lock = Lock()

    def stop(self):  # type: () -> None
        self.service_finder.stop_search_thread()

    def connection_status(self, test_connection_data):
        return self.service_finder.process(test_connection_data.pos_id, test_connection_data.fiscal_date, test_connection_data.fiscal_time)

    def add_payment(self, start_payment_data, additional_params=""):
        self.service_finder.lock_sitef()
        try:
            result = self._process_loop(start_payment_data, additional_params)
        finally:
            self.service_finder.release_sitef()
        self.dialog_manager.close_dialogs(start_payment_data.pos_id)
        return result

    def cancel_payment(self):
        with self.cancel_lock:
            self.cancel = True
        return ""

    def finish_payment(self, finish_payment_data):
        self.service_finder.lock_sitef()
        self.logger.debug("SiTEF finish payment started")
        try:
            if not self.current_order:
                self.logger.debug("No order to finish, ignoring...")
                return
            order_id = finish_payment_data.order_id
            pos_id = finish_payment_data.pos_id

            if self.current_order != order_id:
                self.logger.error("order to finish = {}, current order = {}".format(order_id, self.current_order))
                return

            self.logger.debug("will finish with data: {}".format(finish_payment_data))

            self.configura_sitef_interativo(str(self.current_ip), str(self.id_loja), _get_terminal_id(pos_id), 0)

            status = int(finish_payment_data.status)
            fiscal_date = str(finish_payment_data.fiscal_date)
            fiscal_time = str(finish_payment_data.fiscal_time)
            order_identifier = "{}{}".format(pos_id, order_id)
            self.finaliza_sitef_interativo(status, order_identifier, fiscal_date, fiscal_time, None)

            self.current_ip = self.current_order = None
            self.logger.debug("SiTEF finish payment ended")
            return

        finally:
            self.service_finder.release_sitef()

    def _check_finalized_last_order(self, pos_id):
        for _ in xrange(0, 3, 1):
            if self.current_ip and self.current_order:
                order_id = self.current_order
                order = self._get_order_picture(pos_id, order_id)
                if not order:
                    continue
                order = eTree.XML(order).find("Order")
                created_at = order.get("createdAt").replace("-", "").replace(":", "")
                data_fiscal = created_at[:8]
                hora_fiscal = created_at[9:15]
                if order.find("StateHistory/State[@state='PAID']") is not None:
                    status = "1"
                elif order.find("StateHistory/State[@state='VOIDED']") is not None:
                    status = "0"
                else:
                    self.logger.error("Order %s sem status PAID ou VOIDED" % order_id)
                    return
                self.finish_payment(FinishPaymentData(pos_id, order_id, data_fiscal, hora_fiscal, status))
            else:
                return
        else:
            self.logger.warning("Impossivel finalizar order %s" % self.current_order)
        self.current_order = self.current_ip = None

    def _get_order_picture(self, pos_id, order_id):
        try:
            pos_id_to_search = pos_id
            if order_id not in ('', None, 0):
                pos_id_to_search = ''
            params = (pos_id_to_search, order_id, 'false')
            reqbuf = '\x00'.join((str(p) for p in params))
            msg = self.message_bus.send_message("ORDERMGR%s" % pos_id, Message(TK_SLCTRL_OMGR_ORDERPICT, DataType.param, reqbuf))
            params = msg.data.split('\x00')
            if msg.token == DefaultToken.TK_SYS_NAK:
                return None
            return params[2]
        except Exception: # noqa
            self.logger.exception("Exception trying to get last order picture")
            return None

    def get_name(self):
        return "Sitef"

    def _check_pin_pad(self, pos_id):
        self.dialog_manager.show_message(pos_id, "Conectando PinPad")
        time_limit = (time.time() + 5.0)
        while (time.time() < time_limit) and (not self.sitef_dll["VerificaPresencaPinPad"]()):
            time.sleep(0.2)
        self.dialog_manager.close_dialogs(pos_id)

    def _process_loop(self, sitef_loop_data, additional_params=""):
        # type: (StartPaymentData, str) -> PaymentResponse
        self.logger.debug("SiTEF loop started")
        self.cancel = False

        pos_id = sitef_loop_data.pos_id
        terminal_id = _get_terminal_id(pos_id)
        order_id = sitef_loop_data.order_id

        self._check_pin_pad(pos_id)

        ip_sitef = None
        if self.current_order == order_id:
            ip_sitef = self.current_ip
        else:
            ip_sitef = self.service_finder.find_sitef_service()
            self._check_finalized_last_order(pos_id)

        if not ip_sitef:
            self.service_finder.wakeup_search()
            self.logger.warning("No IP available")
            return PaymentResponseMessage("Sem conexao SiTEF")

        api_ret = self.configura_sitef_interativo(str(ip_sitef), str(self.id_loja), terminal_id, 0)
        if api_ret != API_INIT_OK:
            self.service_finder.sitef_unavailable(ip_sitef)
            self._log_api_config_ret_error(api_ret)
            self.logger.warning("IP {} not available".format(ip_sitef))
            return PaymentResponseMessage("Servidor SiTEF Inoperante")

        amount = sitef_loop_data.amount

        tender_type = sitef_loop_data.tender_type
        order_identifier = "{}{}".format(pos_id, order_id)
        fiscal_date = str(sitef_loop_data.fiscal_date)
        fiscal_time = str(sitef_loop_data.fiscal_time)
        operator = str(sitef_loop_data.operator)
        disabled_payments = "[10;17;18;19;27;28;29;34;35;36;42;]"
        api_ret = self.inicia_sitef_interativo(tender_type, amount, order_identifier, fiscal_date, fiscal_time,
                                               operator, "{};{}".format(disabled_payments, additional_params))

        if api_ret != API_LOOP_OK:
            self._log_api_start_ret_error(api_ret)
            return PaymentResponseMessage("Pagamento interrompido")

        self.current_order = order_id
        self.current_ip = ip_sitef

        command = c_long(0)
        field_type = c_long(0)
        min_size = c_long(0)
        max_size = c_long(0)
        buffer_size = 32768
        output_buffer = create_string_buffer('\000' * buffer_size)

        voided = False

        institution_name = None
        card_bin = None
        transaction_date = None
        auth_code = None
        authorizer_name = None
        authorizer_cnpj = None
        card_type = None
        expiration_date = None
        nsu = None
        nsu_host = None
        transaction_processor = None
        receipt_merchant = None
        receipt_customer = None
        id_mercado_pago = None
        menu_title = ""

        while api_ret == API_LOOP_OK:
            keep_going = 0
            with self.cancel_lock:
                if self.cancel:
                    keep_going = -1 if tender_type == 122 else 2

            api_ret = self.continua_sitef_interativo(addressof(command), addressof(field_type), addressof(min_size),
                                                     addressof(max_size), output_buffer, buffer_size, keep_going)
            if api_ret != API_LOOP_OK:
                break

            if not _api_has_data(command):
                if command.value in (SitefActions.SHOW_OPERATOR_MESSAGE, SitefActions.SHOW_OPERATOR_AND_CUSTOMER_MESSAGE):
                    self.dialog_manager.show_message(pos_id, output_buffer.value)

                elif command.value in (SitefActions.CLEAN_OPERATOR_MESSAGE, SitefActions.CLEAN_CUSTOMER_MESSAGE, SitefActions.CLEAN_OPERATOR_AND_CUSTOMER_MESSAGE):
                    self.dialog_manager.close_dialogs(pos_id)

                elif command.value == SitefActions.SHOW_MESSAGE_WITH_CONFIRMATION:
                    self.dialog_manager.show_question(pos_id, output_buffer.value, buttons="$OK")

                elif command.value == SitefActions.SHOW_MESSAGE_WITH_CANCEL_BUTTON:
                    self.dialog_manager.show_message(pos_id, output_buffer.value)

                elif command.value == SitefActions.ASK_PIN_CODE:
                    pin = self.dialog_manager.show_input(pos_id, output_buffer.value, input_type="number")
                    if pin == "CANCELA":
                        self.cancel_payment()
                        output_buffer.value = "0" * max_size.value

                    else:
                        output_buffer.value = str(pin)

                elif command.value == SitefActions.CANCEL_OPERATION:
                    output_buffer.value = "0"
                    time.sleep(1.5)
                    if field_type.value != 111:
                        voided = True

                elif command.value == SitefActions.MENU_TITLE:
                    menu_title = output_buffer.value

                elif command.value == SitefActions.MENU_CONTENT:
                    choices = {option.split(':')[0]: option.split(':')[1] for option in output_buffer.value.split(';') if option}
                    selected_choice = self.dialog_manager.show_choices(pos_id, choices, message=menu_title)
                    output_buffer.value = str(selected_choice)

                elif _should_ignore_command(command):
                    time.sleep(0.5)

                else:
                    self.dialog_manager.show_message(pos_id, "Mensagem {} {}".format(command.value, output_buffer.value))

            if field_type.value == SitefParams.CARD_BIN:
                card_bin = output_buffer.value

            elif field_type.value == SitefParams.TRANSACTION_PROCESSOR:
                transaction_processor = output_buffer.value

            elif field_type.value == SitefParams.CARD_TYPE:
                card_type = output_buffer.value

            elif field_type.value in SitefParams.AUTH_CODE:
                auth_code = output_buffer.value

            elif field_type.value == SitefParams.QR_CODE:
                self.dialog_manager.show_barcode(pos_id, output_buffer.value)

            elif field_type.value == SitefParams.RECEIPT_CUSTOMER:
                receipt_customer = output_buffer.value

            elif field_type.value == SitefParams.RECEIPT_MERCHANT:
                receipt_merchant = output_buffer.value

            elif field_type.value == SitefParams.NSU:
                nsu = output_buffer.value

            elif field_type.value == SitefParams.NSU_HOST:
                nsu_host = output_buffer.value

            elif field_type.value == SitefParams.TRANSACTION_DATE:
                transaction_date = output_buffer.value

            elif field_type.value == SitefParams.AUTHORIZER_NAME:
                authorizer_name = output_buffer.value

            elif field_type.value == SitefParams.INSTITUTION_NAME:
                institution_name = output_buffer.value

            elif field_type.value == SitefParams.EXPIRATION_DATE:
                expiration_date = output_buffer.value

            elif field_type.value == SitefParams.AUTHORIZER_CNPJ:
                authorizer_cnpj = output_buffer.value

            elif field_type.value == SitefParams.ID_MERCADO_PAGO:
                id_mercado_pago = output_buffer.value

            elif field_type.value == SitefParams.DIGITAL_WALLET_ID:
                card_type = output_buffer.value

        if api_ret == API_LOOP_FINISHED:
            self.logger.debug("SiTEF loop finished")
            return PaymentResponseData(
                media=institution_name,
                result=api_ret,
                card_number=card_bin,
                auth_code="{}{}".format(transaction_date, id_mercado_pago) if tender_type == 122 else auth_code,
                approved_amount=amount,
                id_auth=authorizer_name,
                cnpj_auth=authorizer_cnpj,
                bandeira=card_type,
                receipt_merchant=base64.b64encode(receipt_merchant or receipt_customer),
                receipt_customer=base64.b64encode(receipt_customer),
                expiration_date=expiration_date,
                nsu=nsu,
                transaction_processor=transaction_processor,
                nsu_host=nsu_host)

        else:
            if voided:
                return PaymentResponseMessage("Cancelado")

            if api_ret == API_NO_SITEF_COMMUNICATION:
                self.service_finder.sitef_unavailable(ip_sitef)

            return _format_api_error_response(api_ret)

    def _log_api_config_ret_error(self, api_ret):
        error_codes = {
            0: "No Error",
            1: "IP Error",
            2: "Store Code Error",
            3: "Terminal Code Error",
            6: "TCP/IP Error",
            7: "Memory Error",
            8: "CliSiTef Error",
            10: "CliSiTef Access Error"
        }
        self.logger.error("API Config Error: {}".format(error_codes.get(api_ret, "Unknown")))

    def _log_api_start_ret_error(self, api_ret):
        self.logger.warning("API Start Error: {}".format(api_ret))



from model import FinishPaymentData

from ._CommonProcessor import _CommonProcessor


class FinishPaymentProcessor(_CommonProcessor):
    def parse_data(self, data, event_type):
        return FinishPaymentData(*data.split(';'))

    def call_business(self, finish_payment_data):
        # type: (FinishPaymentData) -> str
        return self.payment_router.finish_all_payments(finish_payment_data)



from ._PaymentResponse import PaymentResponse


class PaymentResponseData(PaymentResponse):
    def __init__(self, media, result, card_number, auth_code, approved_amount, id_auth, cnpj_auth, bandeira, receipt_merchant, receipt_customer, expiration_date, nsu, transaction_processor, nsu_host=""):
        self.media = media
        self.result = result
        self.card_number = card_number
        self.auth_code = auth_code
        self.approved_amount = approved_amount
        self.id_auth = id_auth
        self.cnpj_auth = cnpj_auth
        self.bandeira = bandeira
        self.receipt_merchant = receipt_merchant
        self.receipt_customer = receipt_customer
        self.expiration_date = expiration_date
        self.nsu = nsu
        self.transaction_processor = transaction_processor
        self.nsu_host = nsu_host

    def to_xml(self):
        return """<EftXml Media='%s' Result='%s' CardNumber='%sXXXXXXXXXX' AuthCode='%s' ApprovedAmount='%s' IdAuth='%s' CNPJAuth='%s' Bandeira='%s' ReceiptMerchant='%s' ReceiptCustomer='%s' ExpirationDate='%s' NSU='%s' TransactionProcessor='%s' NSUHost='%s'/>""" % (
            self.media, self.result, self.card_number, self.auth_code,
            self.approved_amount, self.id_auth, self.cnpj_auth, self.bandeira,
            self.receipt_merchant, self.receipt_customer, self.expiration_date,
            self.nsu, self.transaction_processor, self.nsu_host)



from _StartPaymentProcessor import StartPaymentProcessor
from _CancelPaymentProcessor import CancelPaymentProcessor
from _FinishPaymentProcessor import FinishPaymentProcessor
from _TestConnectionProcessor import TestConnectionProcessor
from _DialogResponseProcessor import DialogResponseProcessor



from ._SitefCreditPaymentProcessor import SitefCreditPaymentProcessor
from ._SitefDebitPaymentProcessor import SitefDebitPaymentProcessor
from ._SitefMercadoPagoPaymentProcessor import SitefMercadoPagoPaymentProcessor
from ._SitefMercadoPagoPaymentProcessor import SitefMercadoPagoPaymentProcessor as SitefCarteirasDigitaisPaymentProcessor
from ._MobileSitefPaymentProcessor import MobileSitefPaymentProcessor



class FinishPaymentData(object):
    def __init__(self, pos_id, order_id, fiscal_date, fiscal_time, status):
        self.pos_id = int(pos_id)
        self.order_id = int(order_id)
        self.fiscal_date = fiscal_date
        self.fiscal_time = fiscal_time
        self.status = int(status)

    def __repr__(self):
        return 'FinishPaymentData(pos_id={}, order_id={}, fiscal_date="{}", fiscal_time="{}", status={})'.format(
            self.pos_id, self.order_id, self.fiscal_date, self.fiscal_time, self.status
        )

    def __str__(self):
        return self.__repr__()



# -*- coding: utf-8 -*-

from _CapptaProcessor import CapptaProcessor


class CapptaCreditPaymentProcessor(object):
    def __init__(self, message_bus, dialog_manager, config, logger):
        self.cappta_processor = CapptaProcessor(message_bus, dialog_manager, config, logger)

    def connection_status(self, test_connection_data):
        return self.cappta_processor.connection_status(test_connection_data)

    def add_payment(self, start_payment_data):
        return self.cappta_processor.add_payment(start_payment_data)

    def cancel_payment(self):
        return self.cappta_processor.cancel_payment()

    def finish_payment(self, finish_payment_data):
        self.cappta_processor.finish_payment(finish_payment_data)

    def get_name(self):
        return self.cappta_processor.get_name()

    def stop(self):
        self.cappta_processor.stop()



class StartPaymentData(object):
    def __init__(self, pos_id, order_id, session_id, operator, tender_type, amount, fiscal_date, fiscal_time,
                 tender_seq):
        self.pos_id = int(pos_id)
        self.order_id = int(order_id)
        self.session_id = session_id
        self.operator = int(operator)
        self.tender_type = int(tender_type)
        self.amount = amount
        self.fiscal_date = fiscal_date
        self.fiscal_time = fiscal_time
        self.tender_seq = int(tender_seq)

    def __repr__(self):
        return 'StartPaymentData(pos_id={}, ' \
               'order_id={}, ' \
               'session_id={}' \
               'operator={}, ' \
               'tender_type={}, ' \
               'amount="{}", ' \
               'fiscal_date="{}", ' \
               'fiscal_time="{}", ' \
               'tender_seq={})'.format(
                   self.pos_id, self.order_id, self.session_id, self.operator, self.tender_type, self.amount,
                   self.fiscal_date, self.fiscal_time, self.tender_seq
               )

    def __str__(self):
        return self.__repr__()



from ._StartPaymentData import StartPaymentData
from ._FinishPaymentData import FinishPaymentData
from ._TestConnectionData import TestConnectionData
from ._EftData import EftData
from ._PaymentResponse import PaymentResponse
from ._PaymentResponseData import PaymentResponseData
from ._PaymentResponseMessage import PaymentResponseMessage



import os

import sysactions
from configurator import Configurator
from mbcontextmessagehandler import MbContextMessageBus, MbContextMessageHandler
from messagehandlerbuilder import ServiceMessageHandlerBuilder
from msgbus import MBEasyContext


def main():
    # type: () -> None

    loader_path = os.environ["LOADERCFG"]

    configurator = Configurator(loader_path)
    configs = configurator.read_loader_configs()
    logger = configurator.configure_logger()

    mb_context = MBEasyContext(configs.component_name)
    message_bus = MbContextMessageBus(mb_context)
    sysactions.mbcontext = mb_context

    service_message_handler_builder = ServiceMessageHandlerBuilder(logger, configs, message_bus)
    message_handler = MbContextMessageHandler(message_bus,
                                              configs.component_name,
                                              configs.component_name,
                                              configs.required_services,
                                              service_message_handler_builder)

    logger.debug("Starting messagebus [{}] ...".format(configs.component_name))
    return message_handler.handle_events()


if __name__ == "__main__":
    main()



from abc import ABCMeta, abstractmethod
from logging import Logger

from cfgtools import Configuration
from dialogmanager import DialogManager
from messagebus import MessageBus, Message, DataType
from model import StartPaymentData, FinishPaymentData, TestConnectionData, EftData, PaymentResponse

TK_ACCOUNT_EFTACTIVITY = 0x00E00005


class PaymentProcessor(object):
    __metaclass__ = ABCMeta

    def __init__(self, message_bus, dialog_manager, config, logger):
        # type: (MessageBus, DialogManager, Configuration, Logger) -> None

        self.message_bus = message_bus
        self.dialog_manager = dialog_manager
        self.config = config
        self.logger = logger

    @abstractmethod
    def connection_status(self, test_connection_data):
        # type: (TestConnectionData) -> bool
        raise NotImplementedError()

    @abstractmethod
    def add_payment(self, start_payment_data):
        # type: (StartPaymentData) -> PaymentResponse
        raise NotImplementedError()

    @abstractmethod
    def cancel_payment(self):
        # type: () -> str
        raise NotImplementedError()

    @abstractmethod
    def finish_payment(self, finish_payment_data):
        # type: (FinishPaymentData) -> str
        raise NotImplementedError()

    @abstractmethod
    def get_name(self):
        # type: () -> str
        raise NotImplementedError()

    def stop(self):
        # type: () -> None
        pass

    def register_eft_activity(self, eft_data):
        # type: (EftData) -> None
        self.message_bus.send_message("account{}".format(eft_data.pos_id),
                                      Message(TK_ACCOUNT_EFTACTIVITY,
                                              DataType.param, eft_data.to_payload()))



from abc import ABCMeta, abstractmethod
from xml.etree import cElementTree as eTree

from interactor.route.order_insert_payment_interactor.dto \
    import OrderInsertPaymentRequest
from interactor.route.electronic_payment_send_responses_interactor.dto \
    import PeripheralElectronicPaymentSendResponsesRequest


class FiscalServiceModel(object):
    __metaclass__ = ABCMeta

    @abstractmethod
    def process_order_fiscal(self, model, pos_ot):
        # type: (eTree, object) -> None

        raise NotImplementedError

    @abstractmethod
    def process_payment(self, model, request):
        # type: (eTree, OrderInsertPaymentRequest) -> None

        raise NotImplementedError

    @abstractmethod
    def send_electronic_payment_message_response(self, model, request):
        # type: (eTree, PeripheralElectronicPaymentSendResponsesRequest) -> None

        raise NotImplementedError



from ._PeripheralElectronicPaymentReadMessagesRequest import PeripheralElectronicPaymentReadMessagesRequest
from ._PeripheralElectronicPaymentReadMessagesResponse import PeripheralElectronicPaymentReadMessagesResponse



import os
import sys

import cfgtools

import logging

from cfgtools import Group
from helper import import_pydevd, config_logger
from messagehandlerbuilder import ElectronicPaymentMessageHandlerBuilder
from msgbus import MBEasyContext
from mbcontextmessagehandler import MbContextMessageBus, MbContextMessageHandler

COMPONENT_NAME = "ElectronicPayment"
DEBUG_PORT = 9132
REQUIRED_SERVICES = "StoreWideConfig"


def main():
    loader_path = os.environ["LOADERCFG"]

    import_pydevd(loader_path, DEBUG_PORT, False)
    config_logger(loader_path, COMPONENT_NAME, max_files=100, max_size=12582912, add_error_handler=True)

    logger = logging.getLogger(COMPONENT_NAME)

    config = cfgtools.read(loader_path).find_group("ElectronicPayment")  # type: Group

    try:
        message_bus = MbContextMessageBus(MBEasyContext(COMPONENT_NAME))

        message_handler_builder = ElectronicPaymentMessageHandlerBuilder(message_bus, config, logger)

        message_handler = MbContextMessageHandler(
            message_bus,
            config.find_value("ServiceName"),
            "Payment",
            REQUIRED_SERVICES,
            message_handler_builder)
        return message_handler.handle_events()
    except:
        logger.exception('exception on start')
        raise



import sys
from logging import Logger

from cfgtools import Group
from dialogmanager import DialogManager
from model import TestConnectionData
from typing import Optional, Dict, Tuple, List

import paymentprocessor


class PaymentError(RuntimeError):
    def __repr__(self):
        return self.message


class PaymentNotMapped(PaymentError):
    def __init__(self, tender_id):
        self.message = "Payment {} not mapped".format(tender_id)

    def __repr__(self):
        return self.message


class ConfigurationNotFound(PaymentError):
    def __init__(self, configuration):
        self.message = "Configuration {} not found".format(configuration)


class PaymentNotFound(PaymentError):
    def __init__(self, payment_type):
        self.message = "Payment type {} not found".format(payment_type)


def _get_payment_class_reference(group_name):
    class_ref = getattr(sys.modules["paymentprocessor"], "{}PaymentProcessor".format(group_name), None)
    if class_ref is None:
        raise PaymentNotFound(group_name)
    return class_ref


class PaymentRouter(object):
    def __init__(self, message_bus, dialog_manager, config, logger):
        self.message_bus = message_bus
        self.dialog_manager = dialog_manager  # type: DialogManager
        self._config = config  # type: Group
        self._logger = logger  # type: Logger

        self._current_payment_processor = None  # type: paymentprocessor.PaymentProcessor
        self._payment_route = {}  # type: Dict[int, paymentprocessor.PaymentProcessor]
        self._payment_processors = []  # type: List[paymentprocessor.PaymentProcessor]
        self._fill_payment_routes()

    def _fill_payment_routes(self):
        try:
            electronic_types = self._config.find_group("ElectronicTypes")
            if not electronic_types:
                raise ConfigurationNotFound("ElectronicTypes")
            for group in electronic_types.groups:
                class_ref = _get_payment_class_reference(group.name)
                class_instance = class_ref(self.message_bus, self.dialog_manager, group, self._logger)
                self._payment_processors.append(class_instance)
                for tender_id in group.find_values("TenderIds") or []:
                    self._payment_route[int(tender_id)] = class_instance
                    self._logger.debug("Associated {} to tender id {}".format(group.name, tender_id))
        except Exception as _:
            self._logger.exception("Exception creating payment routes")
            raise

    def get_payment_processor(self, tender_id=None):
        # type: (Optional[int]) -> paymentprocessor.PaymentProcessor
        if tender_id is None:
            return self._current_payment_processor
        if tender_id not in self._payment_route:
            raise PaymentNotMapped(tender_id)
        self._current_payment_processor = self._payment_route[tender_id]
        return self._current_payment_processor

    def get_connection_status(self, test_connection_data):
        # type: (TestConnectionData) -> Tuple[Tuple[str, bool]]

        values = self._payment_route.itervalues()
        return tuple((p.get_name(), p.connection_status(test_connection_data)) for p in values)

    def stop_processors(self):
        for instance in self._payment_processors:
            instance.stop()

    def finish_all_payments(self, data):
        for processor in self._payment_processors:
            processor.finish_payment(data)



from model import EftData, PaymentResponseMessage
from paymentprocessor import PaymentProcessor
from ._SitefProcessor import stop_sitef_processor, get_sitef_processor

from sysdefs import eft


class SitefMercadoPagoPaymentProcessor(PaymentProcessor):
    def __init__(self, message_bus, dialog_manager, config, logger):
        super(SitefMercadoPagoPaymentProcessor, self).__init__(message_bus, dialog_manager, config, logger)
        self.sitef_processor = get_sitef_processor(message_bus, dialog_manager, config, logger)
        self.show_qr_code = config.find_value("ShowQRCode", "false").lower() == "true"
        self.allowed_payments = config.find_values("AllowedPayments") or []
        self.forbidden_payments = config.find_values("ForbiddenPayments") or []
        self.additional_data = self._get_additional_data()

    def connection_status(self, test_connection_data):
        return self.sitef_processor.connection_status(test_connection_data)

    def _get_additional_data(self):
        additional_data_list = []
        if self.show_qr_code:
            additional_data_list.append("{DevolveStringQRCode=1}")
        if self.allowed_payments:
            additional_data_list.append("{{CarteirasDigitaisHabilitadas={}}}".format(';'.join(self.allowed_payments)))
        if self.forbidden_payments:
            additional_data_list.append("{{RestricoesCarteirasDigitais={}}}".format(';'.join(self.forbidden_payments)))
        return ';'.join(additional_data_list)

    def add_payment(self, start_payment_data):
        start_payment_data.tender_type = 122
        ret = self.sitef_processor.add_payment(start_payment_data, self.additional_data)
        self.register_eft_activity(EftData(start_payment_data.pos_id, start_payment_data.session_id, eft.EFT_CREDITSALE,
                                           0 if isinstance(ret, PaymentResponseMessage) else 1,
                                           start_payment_data.amount, orderid=start_payment_data.order_id))
        return ret

    def cancel_payment(self):
        return self.sitef_processor.cancel_payment()

    def finish_payment(self, finish_payment_data):
        return self.sitef_processor.finish_payment(finish_payment_data)

    def get_name(self):
        return self.sitef_processor.get_name()

    def stop(self):
        stop_sitef_processor()



from logging import Logger

from httpmessageprocessor import HttpMessageProcessorMessageHandler
from httpmessageprocessorutil.automapped import AutoMappedMessageProcessor
from interactor.event import ElectronicPaymentEventInteractor
from interactor.route.cache_electronic_payment_interactor import \
    CacheElectronicPaymentInteractor
from interactor.route.cache_electronic_payment_interactor.dto import \
    CachePeripheralElectronicPaymentRequest
from interactor.route.customization_get_styles_interactor import CustomizationGetStylesInteractor
from interactor.route.customization_get_styles_interactor.dto import CustomizationGetStylesRequest
from interactor.route.menu_get_images_interactor import MenuGetImagesInteractor
from interactor.route.menu_get_images_interactor.dto._MenuGetImagesRequest import MenuGetImagesRequest
from interactor.route.menu_get_navigation_interactor \
    import MenuGetNavigationInteractor
from interactor.route.menu_get_navigation_interactor.dto import \
    MenuGetNavigationRequest
from interactor.route.menu_get_products_interactor import MenuGetProductsInteractor
from interactor.route.menu_get_products_interactor.dto import MenuGetProductsRequest
from interactor.route.menu_get_ruptured_products_interactor \
    import MenuGetRupturedProducts
from interactor.route.menu_get_ruptured_products_interactor.dto import \
    MenuGetRupturedProductsRequest
from interactor.route.menu_get_banners_interactor import MenuGetBannersInteractor
from interactor.route.menu_get_banners_interactor.dto import MenuGetBannersRequest
from interactor.route.order_add_items_interactor import OrderAddItemsInteractor
from interactor.route.order_add_items_interactor.dto import OrderAddItemsRequest
from interactor.route.order_add_properties_interactor \
    import OrderAddPropertiesInteractor
from interactor.route.order_add_properties_interactor.dto \
    import OrderAddPropertiesRequest
from interactor.route.order_apply_coupon_interactor import OrderApplyCouponInteractor
from interactor.route.order_apply_coupon_interactor.dto import OrderApplyCouponRequest
from interactor.route.order_cancel_interactor import OrderCancelInteractor
from interactor.route.order_cancel_interactor.dto import OrderCancelRequest
from interactor.route.order_change_items_quantity_interactor import OrderChangeItemsQuantityInteractor
from interactor.route.order_change_items_quantity_interactor.dto import OrderChangeItemsQuantityRequest
from interactor.route.order_close_shopping_cart_interactor import \
    OrderCloseShoppingCartInteractor
from interactor.route.order_close_shopping_cart_interactor.dto import \
    OrderCloseShoppingCartRequest
from interactor.route.order_create_interactor import OrderCreateInteractor
from interactor.route.order_create_interactor.dto import OrderCreateRequest
from interactor.route.order_delete_line_interactor import OrderDeleteLineInteractor
from interactor.route.order_delete_line_interactor.dto import OrderDeleteLineRequest
from interactor.route.order_finalize_interactor import OrderFinalizeInteractor
from interactor.route.order_finalize_interactor.dto import OrderFinalizeRequest
from interactor.route.order_get_detail_interactor import OrderGetDetailInteractor
from interactor.route.order_get_detail_interactor.dto import OrderGetDetailRequest
from interactor.route.order_insert_payment_interactor \
    import OrderInsertPaymentInteractor
from interactor.route.order_insert_payment_interactor.dto \
    import OrderInsertPaymentRequest
from interactor.route.order_reopen_shopping_cart_interactor import OrderReopenShoppingCartInteractor
from interactor.route.order_reopen_shopping_cart_interactor.dto import OrderReopenShoppingCartRequest
from interactor.route.order_remove_coupon_interactor import OrderRemoveCouponInteractor
from interactor.route.order_remove_coupon_interactor.dto import OrderRemoveCouponRequest
from interactor.route.payment_get_payment_types_interactor import PaymentGetPaymentTypesInteractor
from interactor.route.payment_get_payment_types_interactor.dto import PaymentGetPaymentTypesRequest
from interactor.route.electronic_payment_read_messages_interactor \
    import ElectronicPaymentReadMessagesInteractor
from interactor.route.electronic_payment_read_messages_interactor.dto \
    import PeripheralElectronicPaymentReadMessagesRequest
from interactor.route.electronic_payment_send_responses_interactor \
    import ElectronicPaymentSendResponsesInteractor
from interactor.route.electronic_payment_send_responses_interactor.dto \
    import PeripheralElectronicPaymentSendResponsesRequest
from interactor.route.customization_get_text_interactor import CustomizationGetTextInteractor
from interactor.route.customization_get_text_interactor.dto import CustomizationGetTextRequest
from interactor.route.peripheral_print_text import PeripheralPrintTextInteractor
from interactor.route.peripheral_print_text.dto import PeripheralPrintTextRequest
from interactor.route.peripheral_read_scanner import PeripheralReadScannerInteractor
from interactor.route.peripheral_read_scanner.dto import PeripheralReadScannerRequest
from interactor.route.status_get_store_interactor import StatusGetStoreInteractor
from interactor.route.status_get_store_interactor.dto import StatusGetStoreRequest
from interactor.route.customization_get_store_config_interactor import CustomizationGetStoreConfigInteractor
from interactor.route.customization_get_store_config_interactor.dto import CustomizationGetStoreConfigRequest
from interactor.route.order_cancel_payment_interactor import OrderCancelPaymentInteractor
from interactor.route.order_cancel_payment_interactor.dto import OrderCancelPaymentRequest
from mbcontextmessagehandler import MbContextMessageBus
from messagebus import Message, Event
from messagehandler import MessageHandlerBuilder, MessageHandler
from messageprocessor import MessageProcessor, DefaultMessageProcessorExecutorFactory, MessageProcessorMessageHandler
from messageprocessorutil import LoggingProcessorCallback
from model.config import Config
from model.event import ListenedEvents
from model.exception import ValidationError, \
    AuthValidationErrors, ExternalServiceErrors, OperationErrors
from model.response import Responses
from processor.event import \
    ElectronicPaymentCloseDialogProcessor, ElectronicPaymentShowBarcodeProcessor, \
    ElectronicPaymentShowChoicesProcessor, ElectronicPaymentShowInputProcessor, ElectronicPaymentShowMessageProcessor, \
    ElectronicPaymentShowQuestionProcessor
from pyscripts_cache import PyscriptsCache
from repository import PosRepository
from services import (
    FiscalService,
    OrderService,
    ApiService,
    CouponService,
    ImagesService,
    PaymentService
)
from simplehttprouter import Route
from typing import Dict, Optional


class ServiceMessageHandlerBuilder(MessageHandlerBuilder):

    def __init__(self, logger, config, message_bus, flask_server=False):
        # type: (Logger, Config, MbContextMessageBus, bool) -> None

        self.logger = logger
        self.config = config
        self.message_bus = message_bus
        self.flask_server = flask_server

        self.pos_repository = None
        self.fiscal_service = None
        self.coupon_service = None
        self.order_service = None
        self.api_service = None
        self.modifier_service = None
        self.images_service = None
        self.payment_service = None

        self.pyscripts_cache = None

        self.cache_menu_ruptured_items = {"last_request_date": None, "data": None}
        self.cache_menu_products = None
        self.cache_menu_navigation = []
        self.electronic_messages = []

        self.callbacks = None
        self.message_handler = None

    def build_singletons(self):
        # type: () -> None

        self.callbacks = [LoggingProcessorCallback(self.logger)]

        if self.flask_server:
            self.pos_repository = PosRepository(self.message_bus, self.logger, self.config)
            self.fiscal_service = FiscalService(self.message_bus, self.logger)
            self.coupon_service = CouponService(self.message_bus, self.logger)
            self.pyscripts_cache = PyscriptsCache(self.message_bus.mbcontext)
            self.order_service = OrderService()
            self.images_service = ImagesService()
            self.payment_service = PaymentService(self.message_bus)

            self.fiscal_service.get_electronic_payments_id()
        else:
            self.api_service = ApiService(self.config, self.logger)

            events_processors = self._build_events_processors()
            default_message_processor_executor_factory = DefaultMessageProcessorExecutorFactory(self.callbacks)
            self.message_handler = MessageProcessorMessageHandler(events_processors,
                                                                  None,
                                                                  default_message_processor_executor_factory)

    def build_message_handler(self, message=None, event=None):
        # type: (Optional[Message], Optional[Event]) -> MessageHandler

        if self.flask_server:
            processors_routes = self._build_processors_routes()
            http_message_processor = HttpMessageProcessorMessageHandler(route_processor=processors_routes,
                                                                        callbacks=self.callbacks)
            return http_message_processor
        else:
            return self.message_handler

    def destroy_message_handler(self, message_handler):
        # type: (MessageHandler) -> None

        pass

    def destroy_singletons(self):
        # type: () -> None

        pass

    def _build_events_processors(self):
        # type: () -> Optional[Dict[str, MessageProcessor]]

        electronic_payment_event_interactor = ElectronicPaymentEventInteractor(self.api_service)

        electronic_payment_close_dialog_processor = \
            ElectronicPaymentCloseDialogProcessor(electronic_payment_event_interactor)
        electronic_payment_show_barcode_processor = \
            ElectronicPaymentShowBarcodeProcessor(electronic_payment_event_interactor)
        electronic_payment_show_choices_processor = \
            ElectronicPaymentShowChoicesProcessor(electronic_payment_event_interactor)
        electronic_payment_show_input_processor = \
            ElectronicPaymentShowInputProcessor(electronic_payment_event_interactor)
        electronic_payment_show_message_processor = \
            ElectronicPaymentShowMessageProcessor(electronic_payment_event_interactor)
        electronic_payment_show_question_processor = \
            ElectronicPaymentShowQuestionProcessor(electronic_payment_event_interactor)

        events_processors = {
            ListenedEvents.ELECTRONIC_PAYMENT_CLOSE_DIALOGS: electronic_payment_close_dialog_processor,
            ListenedEvents.ELECTRONIC_PAYMENT_SHOW_BARCODE: electronic_payment_show_barcode_processor,
            ListenedEvents.ELECTRONIC_PAYMENT_SHOW_CHOICES: electronic_payment_show_choices_processor,
            ListenedEvents.ELECTRONIC_PAYMENT_SHOW_INPUT: electronic_payment_show_input_processor,
            ListenedEvents.ELECTRONIC_PAYMENT_SHOW_MESSAGE: electronic_payment_show_message_processor,
            ListenedEvents.ELECTRONIC_PAYMENT_SHOW_QUESTION: electronic_payment_show_question_processor
        }

        return events_processors

    def _build_processors_routes(self):
        # type: () -> Dict[Route, MessageProcessor]

        customization_get_styles_interactor = CustomizationGetStylesInteractor(
                logger=self.logger,
                config=self.config
        )
        order_add_items_interactor = \
            OrderAddItemsInteractor(self.logger, self.config, self.pos_repository)
        order_cancel_interactor = \
            OrderCancelInteractor(self.logger, self.config, self.pos_repository)
        order_delete_line_interactor = \
            OrderDeleteLineInteractor(self.logger, self.config, self.pos_repository)
        order_close_shopping_cart_interactor = \
            OrderCloseShoppingCartInteractor(self.logger, self.config, self.pos_repository, self.order_service)
        order_create_interactor = \
            OrderCreateInteractor(self.logger, self.config, self.pos_repository)
        order_add_properties_interactor = \
            OrderAddPropertiesInteractor(self.logger, self.config, self.pos_repository)
        order_finalize_interactor = \
            OrderFinalizeInteractor(self.logger, self.config, self.pos_repository, self.fiscal_service)
        order_get_detail_interactor = \
            OrderGetDetailInteractor(self.logger, self.config, self.pos_repository, self.order_service)
        order_insert_payment_interactor = \
            OrderInsertPaymentInteractor(self.logger, self.config, self.pos_repository, self.fiscal_service)
        order_change_items_quantity_interactor = \
            OrderChangeItemsQuantityInteractor(self.logger, self.config, self.pos_repository)
        order_reopen_shopping_cart_interactor = OrderReopenShoppingCartInteractor(
            logger=self.logger,
            config=self.config,
            pos_repository=self.pos_repository,
            order_service=self.order_service
        )
        order_apply_coupon_interactor = OrderApplyCouponInteractor(
            logger=self.logger,
            config=self.config,
            pos_repository=self.pos_repository,
            coupon_service=self.coupon_service,
            order_service=self.order_service
        )
        order_remove_coupon_interactor = OrderRemoveCouponInteractor(
            logger=self.logger,
            config=self.config,
            pos_repository=self.pos_repository,
            order_service=self.order_service
        )
        menu_get_products_interactor = \
            MenuGetProductsInteractor(self.logger, self.config, self.pos_repository, self.cache_menu_products)
        menu_get_ruptured_products = \
            MenuGetRupturedProducts(self.logger, self.config, self.pos_repository, self.cache_menu_ruptured_items)
        menu_get_navigation_interactor = MenuGetNavigationInteractor(
            logger=self.logger,
            config=self.config,
            pos_repository=self.pos_repository,
            cache_navigation=self.cache_menu_navigation
        )
        menu_get_images_interactor = MenuGetImagesInteractor(self.logger, self.config, self.images_service)
        menu_get_banners_interactor = MenuGetBannersInteractor(
            logger=self.logger,
            config=self.config
        )
        payment_get_payment_types_interactor = PaymentGetPaymentTypesInteractor(
            self.logger,
            self.config,
            self.pos_repository,
            self.payment_service
        )
        peripheral_electronic_payment_read_messages_interactor = \
            ElectronicPaymentReadMessagesInteractor(self.logger,
                                                    self.config,
                                                    self.pos_repository,
                                                    self.fiscal_service,
                                                    self.electronic_messages)
        peripheral_electronic_payment_send_responses_interactor = \
            ElectronicPaymentSendResponsesInteractor(self.logger,
                                                     self.config,
                                                     self.pos_repository,
                                                     self.fiscal_service,
                                                     self.electronic_messages)
        peripheral_print_text_interactor = \
            PeripheralPrintTextInteractor(self.logger, self.config, self.pos_repository)
        peripheral_read_scanner_interactor = \
            PeripheralReadScannerInteractor(self.logger, self.config, self.pos_repository)
        status_get_store_interactor = \
            StatusGetStoreInteractor(self.logger, self.config, self.pos_repository)
        cache_peripheral_electronic_payment_interactor = \
            CacheElectronicPaymentInteractor(self.logger, self.config, self.electronic_messages)

        customization_get_store_config_interactor = CustomizationGetStoreConfigInteractor(
            logger=self.logger,
            config=self.config,
            pos_repository=self.pos_repository
        )

        customization_get_text_interactor = CustomizationGetTextInteractor(
            self.logger,
            self.config,
            self.pos_repository
        )

        order_cancel_payment_interactor = OrderCancelPaymentInteractor(
            self.logger,
            self.config,
            self.pos_repository
        )

        processor_routes = {
            Route("GET", "/order/getDetail/{posId}"): AutoMappedMessageProcessor(
                    OrderGetDetailRequest,
                    order_get_detail_interactor,
                    {
                        ValidationError: Responses.ValidationError,
                        AuthValidationErrors: Responses.AuthValidation,
                        ExternalServiceErrors: Responses.ExternalServicesError,
                        OperationErrors: Responses.OperationErrors
                    }),

            Route("POST", "/order/create/{posId}"): AutoMappedMessageProcessor(
                    OrderCreateRequest,
                    order_create_interactor,
                    {
                        ValidationError: Responses.ValidationError,
                        AuthValidationErrors: Responses.AuthValidation,
                        ExternalServiceErrors: Responses.ExternalServicesError,
                        OperationErrors: Responses.OperationErrors
                    },
                    success_status=201),

            Route("POST", "/order/addProperties/{posId}"): AutoMappedMessageProcessor(
                    OrderAddPropertiesRequest,
                    order_add_properties_interactor,
                    {
                        ValidationError: Responses.ValidationError,
                        AuthValidationErrors: Responses.AuthValidation,
                        ExternalServiceErrors: Responses.ExternalServicesError,
                        OperationErrors: Responses.OperationErrors
                    },
                    success_status=204),

            Route("POST", "/order/addItems/{posId}"): AutoMappedMessageProcessor(
                    OrderAddItemsRequest,
                    order_add_items_interactor,
                    {
                        ValidationError: Responses.ValidationError,
                        AuthValidationErrors: Responses.AuthValidation,
                        ExternalServiceErrors: Responses.ExternalServicesError,
                        OperationErrors: Responses.OperationErrors
                    },
                    success_status=204),

            Route("POST", "/order/changeItemsQuantity/{posId}"): AutoMappedMessageProcessor(
                    OrderChangeItemsQuantityRequest,
                    order_change_items_quantity_interactor,
                    {
                        ValidationError: Responses.ValidationError,
                        AuthValidationErrors: Responses.AuthValidation,
                        ExternalServiceErrors: Responses.ExternalServicesError,
                        OperationErrors: Responses.OperationErrors
                    },
                    success_status=204),

            Route("POST", "/order/insertPayment/{posId}"): AutoMappedMessageProcessor(
                    OrderInsertPaymentRequest,
                    order_insert_payment_interactor,
                    {
                        ValidationError: Responses.ValidationError,
                        AuthValidationErrors: Responses.AuthValidation,
                        ExternalServiceErrors: Responses.ExternalServicesError,
                        OperationErrors: Responses.OperationErrors
                    }),

            Route("DELETE", "/order/cancelPayment/{posId}/{tenderId}"): AutoMappedMessageProcessor(
                    OrderCancelPaymentRequest,
                    order_cancel_payment_interactor,
                    {
                        ValidationError: Responses.ValidationError,
                        AuthValidationErrors: Responses.AuthValidation,
                        ExternalServiceErrors: Responses.ExternalServicesError,
                        OperationErrors: Responses.OperationErrors
                    }),

            Route("POST", "/order/cancel/{posId}"): AutoMappedMessageProcessor(
                    OrderCancelRequest,
                    order_cancel_interactor,
                    {
                        ValidationError: Responses.ValidationError,
                        AuthValidationErrors: Responses.AuthValidation,
                        ExternalServiceErrors: Responses.ExternalServicesError,
                        OperationErrors: Responses.OperationErrors
                    },
                    success_status=204),

            Route("DELETE", "/order/deleteLine/{posId}"): AutoMappedMessageProcessor(
                    OrderDeleteLineRequest,
                    order_delete_line_interactor,
                    {
                        ValidationError: Responses.ValidationError,
                        AuthValidationErrors: Responses.AuthValidation,
                        ExternalServiceErrors: Responses.ExternalServicesError,
                        OperationErrors: Responses.OperationErrors
                    },
                    success_status=204),

            Route("POST", "/order/closeShoppingCart/{posId}"): AutoMappedMessageProcessor(
                    OrderCloseShoppingCartRequest,
                    order_close_shopping_cart_interactor,
                    {
                        ValidationError: Responses.ValidationError,
                        AuthValidationErrors: Responses.AuthValidation,
                        ExternalServiceErrors: Responses.ExternalServicesError,
                        OperationErrors: Responses.OperationErrors
                    }),

            Route("POST", "/order/reopenShoppingCart/{posId}"): AutoMappedMessageProcessor(
                    request_type=OrderReopenShoppingCartRequest,
                    interactor=order_reopen_shopping_cart_interactor,
                    exception_map={
                        ValidationError: Responses.ValidationError,
                        AuthValidationErrors: Responses.AuthValidation,
                        ExternalServiceErrors: Responses.ExternalServicesError,
                        OperationErrors: Responses.OperationErrors
                    }
            ),

            Route("POST", "/order/finalize/{posId}"): AutoMappedMessageProcessor(
                    OrderFinalizeRequest,
                    order_finalize_interactor,
                    {
                        ValidationError: Responses.ValidationError,
                        AuthValidationErrors: Responses.AuthValidation,
                        ExternalServiceErrors: Responses.ExternalServicesError,
                        OperationErrors: Responses.OperationErrors
                    },
                    success_status=204),

            Route("POST", "/order/applyCoupon/{posId}"): AutoMappedMessageProcessor(
                    OrderApplyCouponRequest,
                    order_apply_coupon_interactor,
                    {
                        ValidationError: Responses.ValidationError,
                        AuthValidationErrors: Responses.AuthValidation,
                        ExternalServiceErrors: Responses.ExternalServicesError,
                        OperationErrors: Responses.OperationErrors
                    },
                    success_status=200),

            Route("DELETE", "/order/removeCoupon/{posId}"): AutoMappedMessageProcessor(
                    OrderRemoveCouponRequest,
                    order_remove_coupon_interactor,
                    {
                        ValidationError: Responses.ValidationError,
                        AuthValidationErrors: Responses.AuthValidation,
                        ExternalServiceErrors: Responses.ExternalServicesError,
                        OperationErrors: Responses.OperationErrors
                    }),

            Route("GET", "/menu/products"): AutoMappedMessageProcessor(
                    MenuGetProductsRequest,
                    menu_get_products_interactor,
                    {
                        ValidationError: Responses.ValidationError,
                        AuthValidationErrors: Responses.AuthValidation,
                        ExternalServiceErrors: Responses.ExternalServicesError,
                        OperationErrors: Responses.OperationErrors
                    },
                    response_content_type="application/gzip"),

            Route("GET", "/menu/rupturedProducts"): AutoMappedMessageProcessor(
                    MenuGetRupturedProductsRequest,
                    menu_get_ruptured_products,
                    {
                        ValidationError: Responses.ValidationError,
                        AuthValidationErrors: Responses.AuthValidation,
                        ExternalServiceErrors: Responses.ExternalServicesError,
                        OperationErrors: Responses.OperationErrors
                    }),

            Route("GET", "/menu/navigation/{posId}"): AutoMappedMessageProcessor(
                    MenuGetNavigationRequest,
                    menu_get_navigation_interactor,
                    {
                        ValidationError: Responses.ValidationError,
                        AuthValidationErrors: Responses.AuthValidation,
                        ExternalServiceErrors: Responses.ExternalServicesError,
                        OperationErrors: Responses.OperationErrors
                    }),

            Route("GET", "/menu/images"): AutoMappedMessageProcessor(
                    MenuGetImagesRequest,
                    menu_get_images_interactor,
                    {
                        ValidationError: Responses.ValidationError,
                        AuthValidationErrors: Responses.AuthValidation,
                        ExternalServiceErrors: Responses.ExternalServicesError,
                        OperationErrors: Responses.OperationErrors
                    }),

            Route("GET", "/menu/banners"): AutoMappedMessageProcessor(
                    MenuGetBannersRequest,
                    menu_get_banners_interactor,
                    {
                        AuthValidationErrors: Responses.AuthValidation
                    }),

            Route("GET", "/payment/paymentTypes"): AutoMappedMessageProcessor(
                    PaymentGetPaymentTypesRequest,
                    payment_get_payment_types_interactor,
                    {
                        ValidationError: Responses.ValidationError,
                        AuthValidationErrors: Responses.AuthValidation,
                        ExternalServiceErrors: Responses.ExternalServicesError,
                        OperationErrors: Responses.OperationErrors
                    }),

            Route("POST", "/peripheral/electronicPayment/readMessages/{posId}"): AutoMappedMessageProcessor(
                    PeripheralElectronicPaymentReadMessagesRequest,
                    peripheral_electronic_payment_read_messages_interactor,
                    {
                        ValidationError: Responses.ValidationError,
                        AuthValidationErrors: Responses.AuthValidation,
                        ExternalServiceErrors: Responses.ExternalServicesError,
                        OperationErrors: Responses.OperationErrors
                    }),

            Route("POST", "/peripheral/electronicPayment/sendResponse/{posId}"): AutoMappedMessageProcessor(
                    PeripheralElectronicPaymentSendResponsesRequest,
                    peripheral_electronic_payment_send_responses_interactor,
                    {
                        ValidationError: Responses.ValidationError,
                        AuthValidationErrors: Responses.AuthValidation,
                        ExternalServiceErrors: Responses.ExternalServicesError,
                        OperationErrors: Responses.OperationErrors
                    },
                    success_status=204),

            Route("POST", "/peripheral/printText/{posId}"): AutoMappedMessageProcessor(
                    PeripheralPrintTextRequest,
                    peripheral_print_text_interactor,
                    {
                        ValidationError: Responses.ValidationError,
                        AuthValidationErrors: Responses.AuthValidation,
                        ExternalServiceErrors: Responses.ExternalServicesError
                    },
                    success_status=204),

            Route("GET", "/peripheral/readScanner/{posId}"): AutoMappedMessageProcessor(
                    PeripheralReadScannerRequest,
                    peripheral_read_scanner_interactor,
                    {
                        ValidationError: Responses.ValidationError,
                        AuthValidationErrors: Responses.AuthValidation,
                        ExternalServiceErrors: Responses.ExternalServicesError,
                        OperationErrors: Responses.OperationErrors
                    },
                    success_status=200),

            Route("GET", "/status/store/{posId}"): AutoMappedMessageProcessor(
                    StatusGetStoreRequest,
                    status_get_store_interactor,
                    {
                        ValidationError: Responses.ValidationError,
                        AuthValidationErrors: Responses.AuthValidation,
                        ExternalServiceErrors: Responses.ExternalServicesError,
                        OperationErrors: Responses.OperationErrors
                    }),

            Route("POST", "/cache/peripheral/electronicPayment"): AutoMappedMessageProcessor(
                    CachePeripheralElectronicPaymentRequest,
                    cache_peripheral_electronic_payment_interactor,
                    {},
                    success_status=204),

            Route("GET", "/customization/getStyles"): AutoMappedMessageProcessor(
                    request_type=CustomizationGetStylesRequest,
                    interactor=customization_get_styles_interactor,
                    exception_map={
                        ValidationError: Responses.ValidationError,
                        AuthValidationErrors: Responses.AuthValidation,
                        ExternalServiceErrors: Responses.ExternalServicesError,
                        OperationErrors: Responses.OperationErrors
                    }
            ),

            Route("GET", "/customization/getText"): AutoMappedMessageProcessor(
                    CustomizationGetTextRequest,
                    customization_get_text_interactor,
                    {
                        ValidationError: Responses.ValidationError,
                        AuthValidationErrors: Responses.AuthValidation,
                        ExternalServiceErrors: Responses.ExternalServicesError
                    }),

            Route("GET", "/customization/storeConfig/{posId}"): AutoMappedMessageProcessor(
                    CustomizationGetStoreConfigRequest,
                    customization_get_store_config_interactor,
                    {
                        ValidationError: Responses.ValidationError,
                        AuthValidationErrors: Responses.AuthValidation,
                        ExternalServiceErrors: Responses.ExternalServicesError,
                        OperationErrors: Responses.OperationErrors
                    })
        }

        return processor_routes



# coding=utf-8
import base64
import time

from model import EftData, PaymentResponseData
from paymentprocessor import PaymentProcessor

from sysdefs import eft


class FakePaymentProcessor(PaymentProcessor):
    def connection_status(self, test_connection_data):
        return True

    def add_payment(self, start_payment_data):
        pos_id = start_payment_data.pos_id
        session_id = start_payment_data.session_id
        self.register_eft_activity(EftData(pos_id, session_id, eft.EFT_CREDITSALE, 1,
                                           start_payment_data.amount, orderid=start_payment_data.order_id))
        self.dialog_manager.close_dialogs(pos_id)
        return PaymentResponseData(
            '',
            '0',
            '4111XXXXXXXXXXXX',
            '1302',
            start_payment_data.amount,
            '08496898000142',
            "68536379000192",
            '4',
            base64.b64encode("Recibo de teste.\nSitef FAKE"),
            base64.b64encode("Recibo de teste.\nSitef FAKE"),
            '05/2020',
            '1234',
            "00051")

    def cancel_payment(self):
        return ""

    def finish_payment(self, finish_payment_data):
        return ""

    def get_name(self):
        return "FakeElectronicPayment"
